@@ -50,11 +50,11 @@ class TQCursor;
 class TQAccel;
 class KURL;
 class KTempFile;
-class KToggleAction;
-class KRecentFilesAction;
-class KProcess;
-class KConfig;
-class KAction;
+class TDEToggleAction;
+class TDERecentFilesAction;
+class TDEProcess;
+class TDEConfig;
+class TDEAction;
 
 
 namespace Rosegarden
@@ -98,11 +98,11 @@ class AudioManagerDialog;
   * and statusbar. An instance of RosegardenGUIView creates your center view, which is connected
   * to the window's Doc object.
   * RosegardenGUIApp reimplements the methods that KTMainWindow provides for main window handling and supports
-  * full session management as well as keyboard accelerator configuration by using KAccel.
+  * full session management as well as keyboard accelerator configuration by using TDEAccel.
   * @see KTMainWindow
-  * @see KApplication
-  * @see KConfig
-  * @see KAccel
+  * @see TDEApplication
+  * @see TDEConfig
+  * @see TDEAccel
   *
   * @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
   * @version KDevelop version 0.4 code generation
@@ -110,7 +110,7 @@ class AudioManagerDialog;
 class RosegardenGUIApp : public KDockMainWindow, virtual public RosegardenIface
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
   friend class RosegardenGUIView;
 
@@ -440,11 +440,11 @@ protected:
     /**
      * saves the window properties for each open window during session
      * end to the session config file, including saving the currently
-     * opened file by a temporary filename provided by KApplication.
+     * opened file by a temporary filename provided by TDEApplication.
      *
      * @see KTMainWindow#saveProperties
      */
-    virtual void saveGlobalProperties(KConfig *_cfg);
+    virtual void saveGlobalProperties(TDEConfig *_cfg);
 
     /**
      * reads the session config file and restores the application's
@@ -453,7 +453,7 @@ protected:
      *
      * @see KTMainWindow#readProperties
      */
-    virtual void readGlobalProperties(KConfig *_cfg);
+    virtual void readGlobalProperties(TDEConfig *_cfg);
 
     /**
      * Create a new audio file for the sequencer and return the
@@ -674,7 +674,7 @@ public slots:
      */
     void slotPrintLilyPond();
     void slotPreviewLilyPond();
-    void slotLilyPondViewProcessExited(KProcess *);
+    void slotLilyPondViewProcessExited(TDEProcess *);
 
     /**
      * Let the user enter a MusicXml file to export to
@@ -1132,7 +1132,7 @@ public slots:
     /**
      * Called when the sequencer auxiliary process exits
      */
-    void slotSequencerExited(KProcess*);
+    void slotSequencerExited(TDEProcess*);
 
     /// When the transport closes 
     void slotCloseTransport();
@@ -1319,7 +1319,7 @@ public slots:
      * kxmlguiclient.h just for one typedef.
      *
      * Hopefully we'll be able to get rid of this eventually,
-     * I should slip this in KMainWindow for KDE 4.
+     * I should slip this in TDEMainWindow for KDE 4.
      */
     void slotStateChanged(TQString, bool noReverse);
 
@@ -1550,7 +1550,7 @@ private:
 
     bool m_actionsSetup;
 
-    KRecentFilesAction* m_fileRecent;
+    TDERecentFilesAction* m_fileRecent;
 
     /**
      * view is the main widget which represents your working area. The
@@ -1572,39 +1572,39 @@ private:
     RosegardenGUIDoc* m_doc;
 
     /**
-     * KAction pointers to enable/disable actions
+     * TDEAction pointers to enable/disable actions
      */
-    KRecentFilesAction* m_fileOpenRecent;
+    TDERecentFilesAction* m_fileOpenRecent;
 
-    KToggleAction* m_viewToolBar;
-    KToggleAction* m_viewToolsToolBar;
-    KToggleAction* m_viewTracksToolBar;
-    KToggleAction* m_viewEditorsToolBar;
-    KToggleAction* m_viewZoomToolBar;
-    KToggleAction* m_viewStatusBar;
-    KToggleAction* m_viewTransport;
-    KToggleAction* m_viewTransportToolBar;
-    KToggleAction* m_viewTrackLabels;
-    KToggleAction* m_viewRulers;
-    KToggleAction* m_viewTempoRuler;
-    KToggleAction* m_viewChordNameRuler;
-    KToggleAction* m_viewPreviews;
-    KToggleAction* m_viewSegmentLabels;
-    KToggleAction* m_enableMIDIrouting;
+    TDEToggleAction* m_viewToolBar;
+    TDEToggleAction* m_viewToolsToolBar;
+    TDEToggleAction* m_viewTracksToolBar;
+    TDEToggleAction* m_viewEditorsToolBar;
+    TDEToggleAction* m_viewZoomToolBar;
+    TDEToggleAction* m_viewStatusBar;
+    TDEToggleAction* m_viewTransport;
+    TDEToggleAction* m_viewTransportToolBar;
+    TDEToggleAction* m_viewTrackLabels;
+    TDEToggleAction* m_viewRulers;
+    TDEToggleAction* m_viewTempoRuler;
+    TDEToggleAction* m_viewChordNameRuler;
+    TDEToggleAction* m_viewPreviews;
+    TDEToggleAction* m_viewSegmentLabels;
+    TDEToggleAction* m_enableMIDIrouting;
 
-    KAction *m_playTransport;
-    KAction *m_stopTransport;
-    KAction *m_rewindTransport;
-    KAction *m_ffwdTransport; 
-    KAction *m_recordTransport;
-    KAction *m_rewindEndTransport;
-    KAction *m_ffwdEndTransport;
+    TDEAction *m_playTransport;
+    TDEAction *m_stopTransport;
+    TDEAction *m_rewindTransport;
+    TDEAction *m_ffwdTransport; 
+    TDEAction *m_recordTransport;
+    TDEAction *m_rewindEndTransport;
+    TDEAction *m_ffwdEndTransport;
 
-    KProcess* m_sequencerProcess;
+    TDEProcess* m_sequencerProcess;
     bool m_sequencerCheckedIn;
 
 #ifdef HAVE_LIBJACK
-    KProcess* m_jackProcess;
+    TDEProcess* m_jackProcess;
 #endif // HAVE_LIBJACK
 
     ZoomSlider<double> *m_zoomSlider;
@@ -1663,7 +1663,7 @@ private:
 
     static RosegardenGUIApp *m_myself;
 
-    static std::map<KProcess *, KTempFile *> m_lilyTempFileMap;
+    static std::map<TDEProcess *, KTempFile *> m_lilyTempFileMap;
 
     // Used to fetch the current sequencer position from the mmapped sequencer information file
     //
@@ -1677,8 +1677,8 @@ private:
 
     RosegardenParameterArea *m_parameterArea;
 
-    KAction *m_setQuickMarkerAction;
-    KAction *m_jumpToQuickMarkerAction;
+    TDEAction *m_setQuickMarkerAction;
+    TDEAction *m_jumpToQuickMarkerAction;
     
 #ifdef HAVE_LIRC        
     LircClient *m_lircClient;
