@@ -25,7 +25,7 @@
 
 #include "EventEditDialog.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Strings.h"
 #include "base/Event.h"
 #include "base/MidiTypes.h"
@@ -34,7 +34,7 @@
 #include "base/RealTime.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
 #include <kdialogbase.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqcheckbox.h>
 #include <tqfont.h>
 #include <tqgrid.h>
