@@ -34,7 +34,7 @@
 #include "NotationCanvasView.h"
 #include <string>
 #include <kprocess.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <tqmap.h>
 #include <tqsize.h>
 #include <tqstring.h>
@@ -54,8 +54,8 @@ class TQCanvasItem;
 class TQCanvas;
 class KProgress;
 class KComboBox;
-class KActionMenu;
-class KAction;
+class TDEActionMenu;
+class TDEAction;
 
 
 namespace Rosegarden
@@ -109,7 +109,7 @@ class NotationView : public EditView,
     friend class LilyPondExporter;
 
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     explicit NotationView(RosegardenGUIDoc *doc,
@@ -366,7 +366,7 @@ public slots:
      */
     void slotPrintLilyPond();
     void slotPreviewLilyPond();
-    void slotLilyPondViewProcessExited(KProcess *);
+    void slotLilyPondViewProcessExited(TDEProcess *);
 
     /**
      * put the marked text/object into the clipboard and remove it
@@ -1083,7 +1083,7 @@ protected:
     bool m_annotationsVisible;
     bool m_lilyPondDirectivesVisible;
     
-    KAction* m_selectDefaultNote;
+    TDEAction* m_selectDefaultNote;
 
     typedef TQMap<TQString, NoteActionData *> NoteActionDataMap;
     static NoteActionDataMap* m_noteActionDataMap;
@@ -1097,7 +1097,7 @@ protected:
     KComboBox       *m_fontCombo;
     KComboBox       *m_fontSizeCombo;
     KComboBox       *m_spacingCombo;
-    KActionMenu     *m_fontSizeActionMenu;
+    TDEActionMenu     *m_fontSizeActionMenu;
     ScrollBoxDialog *m_pannerDialog;
     TQTimer *m_renderTimer;
 
@@ -1115,14 +1115,14 @@ protected:
     bool m_printMode;
     int m_printSize;
 
-    static std::map<KProcess *, KTempFile *> m_lilyTempFileMap;
+    static std::map<TDEProcess *, KTempFile *> m_lilyTempFileMap;
 
     int m_showHeadersGroup;
     QDeferScrollView * m_headersGroupView;
     HeadersGroup * m_headersGroup;
     TQFrame * m_headersTopFrame;
 
-    KAction * m_showHeadersMenuEntry;
+    TDEAction * m_showHeadersMenuEntry;
 
 };
 
