@@ -25,10 +25,10 @@
 
 #include "NoteInserter.h"
 #include "misc/Debug.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "base/BaseProperties.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
 #include "base/Event.h"
@@ -49,9 +49,9 @@
 #include "NotationStaff.h"
 #include "NotePixmapFactory.h"
 #include "NoteStyleFactory.h"
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <tqiconset.h>
 #include <tqregexp.h>
 #include <tqstring.h>
@@ -71,15 +71,15 @@ NoteInserter::NoteInserter(NotationView* view)
 {
     TQIconSet icon;
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(NotationViewConfigGroup);
     m_autoBeam = config->readBoolEntry("autobeam", true);
     m_matrixInsertType = (config->readNumEntry("inserttype", 0) > 0);
     m_defaultStyle = qstrtostr(config->readEntry
                                ("style", strtoqstr(NoteStyleFactory::DefaultStyle)));
 
-    KToggleAction *autoBeamAction =
-        new KToggleAction(i18n("Auto-Beam when appropriate"), 0, this,
+    TDEToggleAction *autoBeamAction =
+        new TDEToggleAction(i18n("Auto-Beam when appropriate"), 0, this,
                           TQT_SLOT(slotToggleAutoBeam()), actionCollection(),
                           "toggle_auto_beam");
     autoBeamAction->setChecked(m_autoBeam);
@@ -89,7 +89,7 @@ NoteInserter::NoteInserter(NotationView* view)
         icon = TQIconSet
                (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                              makeToolbarPixmap(m_actionsAccidental[i][3])));
-        KRadioAction* noteAction = new KRadioAction(i18n(m_actionsAccidental[i][0]),
+        TDERadioAction* noteAction = new TDERadioAction(i18n(m_actionsAccidental[i][0]),
                                    icon, 0, this,
                                    m_actionsAccidental[i][1],
                                    actionCollection(),
@@ -100,24 +100,24 @@ NoteInserter::NoteInserter(NotationView* view)
     icon = TQIconSet
            (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                          makeToolbarPixmap("dotted-crotchet")));
-    new KToggleAction(i18n("Dotted note"), icon, 0, this,
+    new TDEToggleAction(i18n("Dotted note"), icon, 0, this,
                       TQT_SLOT(slotToggleDot()), actionCollection(),
                       "toggle_dot");
 
     icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                     makeToolbarPixmap("select")));
-    new KAction(i18n("Switch to Select Tool"), icon, 0, this,
+    new TDEAction(i18n("Switch to Select Tool"), icon, 0, this,
                 TQT_SLOT(slotSelectSelected()), actionCollection(),
                 "select");
 
-    new KAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
+    new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
                 TQT_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
     icon = TQIconSet
            (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                          makeToolbarPixmap("rest-crotchet")));
-    new KAction(i18n("Switch to Inserting Rests"), icon, 0, this,
+    new TDEAction(i18n("Switch to Inserting Rests"), icon, 0, this,
                 TQT_SLOT(slotRestsSelected()), actionCollection(),
                 "rests");
 
@@ -606,7 +606,7 @@ void NoteInserter::slotSetDots(unsigned int dots)
 {
     m_noteDots = dots;
 
-    KToggleAction *dotsAction = dynamic_cast<KToggleAction *>
+    TDEToggleAction *dotsAction = dynamic_cast<TDEToggleAction *>
                                 (actionCollection()->action("toggle_dot"));
     if (dotsAction)
         dotsAction->setChecked(dots > 0);
@@ -662,7 +662,7 @@ void NoteInserter::slotToggleDot()
     Note note(m_noteType, m_noteDots);
     TQString actionName(NotationStrings::getReferenceName(note));
     actionName.replace(TQRegExp("-"), "_");
-    KAction *action = m_parentView->actionCollection()->action(actionName.ascii());
+    TDEAction *action = m_parentView->actionCollection()->action(actionName.ascii());
     if (!action) {
         std::cerr << "WARNING: No such action as " << actionName.ascii() << std::endl;
     } else {
@@ -690,7 +690,7 @@ void NoteInserter::slotRestsSelected()
     Note note(m_noteType, m_noteDots);
     TQString actionName(NotationStrings::getReferenceName(note, true));
     actionName.replace(TQRegExp("-"), "_");
-    KAction *action = m_parentView->actionCollection()->action(actionName.ascii());
+    TDEAction *action = m_parentView->actionCollection()->action(actionName.ascii());
     if (!action) {
         std::cerr << "WARNING: No such action as " << actionName.ascii() << std::endl;
     } else {
