@@ -27,7 +27,7 @@
 #include <tqlayout.h>
 
 #include "sound/Midi.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/Colour.h"
