@@ -20,7 +20,7 @@
 
 
 #include <iostream>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <fstream>
 #include <string>
 #include <dirent.h> // for new recording file
@@ -36,10 +36,10 @@
 #endif
 
 #include <kapp.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kprocess.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
+#include <tdeio/netaccess.h>
+#include <tdemessagebox.h>
 
 #include <tqpixmap.h>
 #include <tqpainter.h>
@@ -660,7 +660,7 @@ AudioFileManager::importURL(const KURL &url, int sampleRate)
     emit setOperationName(i18n("Downloading file %1").arg(url.prettyURL()));
 
     TQString localPath = "";
-    if (!KIO::NetAccess::download(url, localPath)) {
+    if (!TDEIO::NetAccess::download(url, localPath)) {
 	KMessageBox::error(0, i18n("Cannot download file %1").arg(url.prettyURL()));
 	throw SoundFile::BadSoundFileException(url.prettyURL().ascii());
     }
@@ -670,10 +670,10 @@ AudioFileManager::importURL(const KURL &url, int sampleRate)
     try {
 	id = importFile(localPath.ascii(), sampleRate);
     } catch (BadAudioPathException ape) {
-	KIO::NetAccess::removeTempFile(localPath);
+	TDEIO::NetAccess::removeTempFile(localPath);
 	throw ape;
     } catch (SoundFile::BadSoundFileException bse) {
-	KIO::NetAccess::removeTempFile(localPath);
+	TDEIO::NetAccess::removeTempFile(localPath);
 	throw bse;
     }
     
@@ -684,7 +684,7 @@ bool
 AudioFileManager::fileNeedsConversion(const std::string &fileName,
                                       int sampleRate)
 {
-    KProcess *proc = new KProcess();
+    TDEProcess *proc = new TDEProcess();
     *proc << "rosegarden-audiofile-importer";
     if (sampleRate > 0) {
         *proc << "-r";
@@ -693,7 +693,7 @@ AudioFileManager::fileNeedsConversion(const std::string &fileName,
     *proc << "-w";
     *proc << fileName.c_str();
 
-    proc->start(KProcess::Block, KProcess::NoCommunication);
+    proc->start(TDEProcess::Block, TDEProcess::NoCommunication);
 
     int es = proc->exitStatus();
     delete proc;
@@ -711,7 +711,7 @@ AudioFileManager::importFile(const std::string &fileName, int sampleRate)
 
     std::cerr << "AudioFileManager::importFile("<< fileName << ", " << sampleRate << ")" << std::endl;
 
-    KProcess *proc = new KProcess();
+    TDEProcess *proc = new TDEProcess();
     *proc << "rosegarden-audiofile-importer";
     if (sampleRate > 0) {
 	*proc << "-r";
@@ -720,7 +720,7 @@ AudioFileManager::importFile(const std::string &fileName, int sampleRate)
     *proc << "-w";
     *proc << fileName.c_str();
 
-    proc->start(KProcess::Block, KProcess::NoCommunication);
+    proc->start(TDEProcess::Block, TDEProcess::NoCommunication);
 
     int es = proc->exitStatus();
     delete proc;
@@ -763,7 +763,7 @@ AudioFileManager::importFile(const std::string &fileName, int sampleRate)
         }
     }
 
-    m_importProcess = new KProcess;
+    m_importProcess = new TDEProcess;
 
     *m_importProcess << "rosegarden-audiofile-importer";
     if (sampleRate > 0) {
@@ -774,7 +774,7 @@ AudioFileManager::importFile(const std::string &fileName, int sampleRate)
     *m_importProcess << fileName.c_str();
     *m_importProcess << (m_audioPath.c_str() + targetName);
     
-    m_importProcess->start(KProcess::NotifyOnExit, KProcess::NoCommunication);
+    m_importProcess->start(TDEProcess::NotifyOnExit, TDEProcess::NoCommunication);
 
     while (m_importProcess->isRunning()) {
 	kapp->processEvents(100);
